@@ -101,7 +101,7 @@ def is_task(tup):
     )
 
 
-def load_fabfile(path):
+def load_fabfile(path, importer=None):
     """
     Import given fabfile path and return (docstring, callables).
 
@@ -109,6 +109,8 @@ def load_fabfile(path):
     dictionary of ``{'name': callable}`` containing all callables which pass
     the "is a Fabric task" test.
     """
+    if importer is None:
+        importer = __import__
     # Get directory and fabfile name
     directory, fabfile = os.path.split(path)
     # If the directory isn't in the PYTHONPATH, add it so our import will work
@@ -129,7 +131,7 @@ def load_fabfile(path):
             sys.path.insert(0, directory)
             del sys.path[i + 1]
     # Perform the import (trimming off the .py)
-    imported = __import__(os.path.splitext(fabfile)[0])
+    imported = importer(os.path.splitext(fabfile)[0])
     # Remove directory from path if we added it ourselves (just to be neat)
     if added_to_path:
         del sys.path[0]
@@ -361,7 +363,14 @@ def _merge(hosts, roles):
             value = value()
         role_hosts += value
     # Return deduped combo of hosts and role_hosts
-    return list(set(hosts + role_hosts))
+    return list(set(_clean_hosts(hosts + role_hosts)))
+
+
+def _clean_hosts(host_list):
+    """
+    Clean host strings to ensure no trailing whitespace, etc.
+    """
+    return [host.strip() for host in host_list]
 
 
 def get_hosts(command, cli_hosts, cli_roles):
@@ -423,7 +432,7 @@ def main():
 
         # Handle --hosts, --roles (comma separated string => list)
         for key in ['hosts', 'roles']:
-            if key in state.env and isinstance(state.env[key], str):
+            if key in state.env and isinstance(state.env[key], basestring):
                 state.env[key] = state.env[key].split(',')
 
         # Handle output control level show/hide
