@@ -19,7 +19,8 @@ from contextlib import closing
 from fabric.context_managers import settings, char_buffered
 from fabric.io import output_loop, input_loop
 from fabric.network import needs_host
-from fabric.state import env, connections, output, win32, default_channel
+from fabric.state import (env, connections, output, win32, default_channel,
+    io_sleep)
 from fabric.utils import abort, indent, warn, puts
 from fabric.thread_handling import ThreadHandler
 from fabric.sftp import SFTP
@@ -693,7 +694,7 @@ def _prefix_env_vars(command):
     return path + command
 
 
-def _execute(channel, command, pty=True, combine_stderr=True,
+def _execute(channel, command, pty=True, combine_stderr=None,
     invoke_shell=False):
     """
     Execute ``command`` over ``channel``.
@@ -701,6 +702,9 @@ def _execute(channel, command, pty=True, combine_stderr=True,
     ``pty`` controls whether a pseudo-terminal is created.
 
     ``combine_stderr`` controls whether we call ``channel.set_combine_stderr``.
+    By default, the global setting for this behavior (:ref:`env.combine_stderr
+    <combine-stderr>`) is consulted, but you may specify ``True`` or ``False``
+    here to override it.
 
     ``invoke_shell`` controls whether we use ``exec_command`` or
     ``invoke_shell`` (plus a handful of other things, such as always forcing a
@@ -712,8 +716,9 @@ def _execute(channel, command, pty=True, combine_stderr=True,
     """
     with char_buffered(sys.stdin):
         # Combine stdout and stderr to get around oddball mixing issues
-        if combine_stderr or env.combine_stderr:
-            channel.set_combine_stderr(True)
+        if combine_stderr is None:
+            combine_stderr = env.combine_stderr
+        channel.set_combine_stderr(combine_stderr)
 
         # Assume pty use, and allow overriding of this either via kwarg or env
         # var.  (invoke_shell always wants a pty no matter what.)
@@ -754,6 +759,7 @@ def _execute(channel, command, pty=True, combine_stderr=True,
                     e = worker.exception
                     if e:
                         raise e[0], e[1], e[2]
+            time.sleep(io_sleep)
 
         # Obtain exit code of remote program now that we're done.
         status = channel.recv_exit_status()
@@ -864,7 +870,7 @@ def _run_command(command, shell=True, pty=True, combine_stderr=True,
 
 
 @needs_host
-def run(command, shell=True, pty=True, combine_stderr=True):
+def run(command, shell=True, pty=True, combine_stderr=None):
     """
     Run a shell command on a remote host.
 
@@ -912,12 +918,17 @@ def run(command, shell=True, pty=True, combine_stderr=True):
 
     .. versionchanged:: 1.0
         The default value of ``pty`` is now ``True``.
+
+    .. versionchanged:: 1.0.2
+        The default value of ``combine_stderr`` is now ``None`` instead of
+        ``True``. However, the default *behavior* is unchanged, as the global
+        setting is still ``True``.
     """
     return _run_command(command, shell, pty, combine_stderr)
 
 
 @needs_host
-def sudo(command, shell=True, pty=True, combine_stderr=True, user=None):
+def sudo(command, shell=True, pty=True, combine_stderr=None, user=None):
     """
     Run a shell command on a remote host, with superuser privileges.
 
@@ -990,17 +1001,23 @@ def local(command, capture=False):
         print("[localhost] local: " + given_command)
     # Tie in to global output controls as best we can; our capture argument
     # takes precedence over the output settings.
+    dev_null = None
     if capture:
         out_stream = subprocess.PIPE
         err_stream = subprocess.PIPE
     else:
-        if output.stdout:
-            out_stream = None
-        if output.stderr:
-            err_stream = None
-    p = subprocess.Popen([wrapped_command], shell=True, stdout=out_stream,
+        dev_null = open(os.devnull, 'w+')
+        # Non-captured, hidden streams are discarded.
+        out_stream = None if output.stdout else dev_null
+        err_stream = None if output.stderr else dev_null
+    try:
+        cmd_arg = wrapped_command if win32 else [wrapped_command]
+        p = subprocess.Popen(cmd_arg, shell=True, stdout=out_stream,
             stderr=err_stream)
-    (stdout, stderr) = p.communicate()
+        (stdout, stderr) = p.communicate()
+    finally:
+        if dev_null is not None:
+            dev_null.close()
     # Handle error condition (deal with stdout being None, too)
     out = _AttributeString(stdout.strip() if stdout else "")
     err = _AttributeString(stderr.strip() if stderr else "")
